@@ -1,4 +1,4 @@
-//@line 38 "/buildbot/linux_build_30/build/mail/base/content/mailCore.js"
+//@line 39 "/buildbot/linux_build/build/mail/base/content/mailCore.js"
 
 /*
  * Core mail routines used by all of the major mail windows (address book, 3-pane, compose and stand alone message window).
@@ -8,6 +8,35 @@
 
 var gCustomizeSheet = false;
 
+function overlayRestoreDefaultSet() {
+  let toolbox = null;
+  if ("arguments" in window && window.arguments[0])
+    toolbox = window.arguments[0];
+  else if (window.frameElement && "toolbox" in window.frameElement)
+    toolbox = window.frameElement.toolbox;
+
+  let mode = toolbox.getAttribute("defaultmode");
+  let align = toolbox.getAttribute("defaultlabelalign");
+  let menulist = document.getElementById("modelist");
+
+  if (mode == "full" && align == "end") {
+    toolbox.setAttribute("mode", "textbesideicon");
+    toolbox.setAttribute("labelalign", align);
+    overlayUpdateToolbarMode("textbesideicon");
+  }
+  else if (mode == "full" && align == ""){
+    toolbox.setAttribute("mode", "full");
+    toolbox.removeAttribute("labelalign");
+    overlayUpdateToolbarMode(mode);
+  }
+
+  restoreDefaultSet();
+
+  if (mode == "full" && align == "end") {
+    menulist.value = "textbesideicon";
+  }
+}
+
 function overlayUpdateToolbarMode(aModeValue)
 {
   let toolbox = null;
@@ -29,6 +58,9 @@ function overlayUpdateToolbarMode(aModeValue)
 
 function overlayOnLoad()
 {
+  let restoreButton = document.getElementById("main-box").querySelector("[oncommand*='restore']");
+  restoreButton.setAttribute("oncommand", "overlayRestoreDefaultSet();");
+
   // Add the textBesideIcon menu item if it's not already there.
   let menuitem = document.getElementById("textbesideiconItem");
   if (!menuitem) {
@@ -46,12 +78,17 @@ function overlayOnLoad()
     toolbox = window.arguments[0];
   else if (window.frameElement && "toolbox" in window.frameElement)
     toolbox = window.frameElement.toolbox;
+
+  document.getElementById("CustomizeToolbarWindow").setAttribute("toolboxId", toolbox.id);
+  toolbox.setAttribute("doCustomization", "true");
+
   let mode = toolbox.getAttribute("mode");
   let align = toolbox.getAttribute("labelalign");
   if (mode == "full" && align == "end")
     toolbox.setAttribute("mode", "textbesideicon");
 
   onLoad();
+  overlayRepositionDialog();
 
   // Re-set and re-persist the mode, if we changed it above.
   if (mode == "full" && align == "end") {
@@ -60,6 +97,27 @@ function overlayOnLoad()
   }
 }
 
+function overlayRepositionDialog()
+{
+  // Position the dialog so it is fully visible on the screen  
+  // (if possible)
+
+  // Seems to be necessary to get the correct dialog height/width
+  window.sizeToContent();
+  var wH  = window.outerHeight;
+  var wW  = window.outerWidth;
+  var sH  = window.screen.height;
+  var sW  = window.screen.width;
+  var sX  = window.screenX;
+  var sY  = window.screenY;
+  var sAL = window.screen.availLeft;
+  var sAT = window.screen.availTop;
+
+  var nX = Math.max(Math.min(sX, sW - wW), sAL);
+  var nY = Math.max(Math.min(sY, sH - wH), sAT);
+  window.moveTo(nX, nY);
+}
+
 function CustomizeMailToolbar(toolboxId, customizePopupId)
 {
   // Disable the toolbar context menu items
@@ -91,16 +149,8 @@ function CustomizeMailToolbar(toolboxId, customizePopupId)
     else
       sheetFrame.setAttribute("src", customizeURL);
 
-    var sheetWidth = sheetFrame.style.width.match(/([0-9]+)px/)[1];
-//@line 132 "/buildbot/linux_build_30/build/mail/base/content/mailCore.js"
-    var rtl = sheetFrame.getAttribute("chromedir") == "rtl";
-    var position = "after_start";
-    if (rtl)
-      position = "after_end";
     document.getElementById("customizeToolbarSheetPopup")
-            .openPopup(toolbox, position,
-                       (window.innerWidth - sheetWidth) / 2, 0);
-//@line 144 "/buildbot/linux_build_30/build/mail/base/content/mailCore.js"
+            .openPopup(toolbox, "after_start", 0, 0);
   }
   else {
     var wintype = document.documentElement.getAttribute("windowtype");
@@ -141,16 +191,24 @@ function MailToolboxCustomizeDone(aEvent, customizePopupId)
   if (this.UpdateMailToolbar != undefined)
     UpdateMailToolbar(focus);
 
-  // The GetMail button is stuck in a strange state right now, since the
-  // customization wrapping preserves its children, but not its initialized
-  // state. Fix that here.
-  if (document.getElementById("button-getmsg")) {
-    // We can't use _teardown here, because it'll remove the Get All menuitem
-    let popup = document.getElementById("button-getMsgPopup");
-    let sep = document.getElementById("button-getAllNewMsgSeparator");
-    while (popup.lastChild != sep)
-      popup.removeChild(popup.lastChild);
+  var toolbox = document.getElementsByAttribute("doCustomization", "true")[0];
+  if (toolbox) {
+    toolbox.removeAttribute("doCustomization");
+
+    // The GetMail button is stuck in a strange state right now, since the
+    // customization wrapping preserves its children, but not its initialized
+    // state. Fix that here.
+    // Fix Bug 565045: Only treat "Get Message Button" if it is in our toolbox
+    var popup = toolbox.getElementsByAttribute("id", "button-getMsgPopup")[0];
+    if (popup) {
+      // We can't use _teardown here, because it'll remove the Get All menuitem
+      let sep = toolbox.getElementsByAttribute("id", "button-getAllNewMsgSeparator")[0];
+      while (popup.lastChild != sep)
+        popup.removeChild(popup.lastChild);
+    }
   }
+  UpdateJunkButton();
+  UpdateReplyButtons();
 }
 
 function onViewToolbarCommand(aEvent, toolboxId)
@@ -281,7 +339,7 @@ function openOptionsDialog(aPaneID, aTabID)
     openDialog("chrome://messenger/content/preferences/preferences.xul","Preferences", features, aPaneID, aTabID);
 }
 
-function openAddonsMgr()
+function openAddonsMgr(aPane)
 {
   const EMTYPE = "Extension:Manager";
   var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
@@ -289,12 +347,17 @@ function openAddonsMgr()
   var theEM = wm.getMostRecentWindow(EMTYPE);
   if (theEM) {
     theEM.focus();
+    if (aPane)
+      theEM.showView(aPane);
     return;
   }
 
   const EMURL = "chrome://mozapps/content/extensions/extensions.xul";
   const EMFEATURES = "chrome,menubar,extra-chrome,toolbar,dialog=no,resizable";
-  window.openDialog(EMURL, "", EMFEATURES);
+  if (aPane)
+    window.openDialog(EMURL, "", EMFEATURES, aPane);
+  else
+    window.openDialog(EMURL, "", EMFEATURES);
 }
 
 function openActivityMgr()
@@ -303,6 +366,13 @@ function openActivityMgr()
     getService(Components.interfaces.nsIActivityManagerUI).show(window);
 }
 
+function openSavedFilesWnd()
+{
+  Components.classes['@mozilla.org/download-manager-ui;1']
+            .getService(Components.interfaces.nsIDownloadManagerUI)
+            .show(window);
+}
+
 function SetBusyCursor(window, enable)
 {
     // setCursor() is only available for chrome windows.
@@ -323,9 +393,9 @@ function SetBusyCursor(window, enable)
 
 function openAboutDialog()
 {
-//@line 379 "/buildbot/linux_build_30/build/mail/base/content/mailCore.js"
+//@line 446 "/buildbot/linux_build/build/mail/base/content/mailCore.js"
   window.openDialog("chrome://messenger/content/aboutDialog.xul", "About", "centerscreen,chrome,resizable=no");
-//@line 381 "/buildbot/linux_build_30/build/mail/base/content/mailCore.js"
+//@line 448 "/buildbot/linux_build/build/mail/base/content/mailCore.js"
 }
 
 /**
@@ -357,13 +427,13 @@ function openFormattedURL(aPrefName)
   protocolSvc.loadURI(uri);
 }
 
-//@line 415 "/buildbot/linux_build_30/build/mail/base/content/mailCore.js"
+//@line 482 "/buildbot/linux_build/build/mail/base/content/mailCore.js"
 
 function getMostRecentMailWindow() {
   let wm = Cc["@mozilla.org/appshell/window-mediator;1"]
              .getService(Components.interfaces.nsIWindowMediator);
 
-//@line 421 "/buildbot/linux_build_30/build/mail/base/content/mailCore.js"
+//@line 488 "/buildbot/linux_build/build/mail/base/content/mailCore.js"
   let win = wm.getMostRecentWindow("mail:3pane", true);
 
   // if we're lucky, this isn't a popup, and we can just return this
@@ -377,7 +447,7 @@ function getMostRecentMailWindow() {
         win = nextWin;
     }
   }
-//@line 447 "/buildbot/linux_build_30/build/mail/base/content/mailCore.js"
+//@line 514 "/buildbot/linux_build/build/mail/base/content/mailCore.js"
 
   return win;
 }
